"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
// Mock crypto-related functions
vitest_1.vi.mock('nostr-crypto-utils', () => ({
    getPublicKey: vitest_1.vi.fn().mockImplementation((privateKey) => {
        // Return a deterministic public key based on private key
        return `pub_${privateKey}`;
    }),
    signEvent: vitest_1.vi.fn().mockImplementation(() => {
        // Return a mock signature
        return 'mock_signature';
    }),
    verifySignature: vitest_1.vi.fn().mockImplementation(() => {
        // Always return true for tests
        return true;
    }),
    encryptMessage: vitest_1.vi.fn().mockImplementation((message) => {
        // Return a mock encrypted message
        return `encrypted_${message}`;
    })
}));
// Mock WebSocket client
vitest_1.vi.mock('nostr-websocket-utils', () => ({
    NostrWSClient: vitest_1.vi.fn().mockImplementation((urls) => ({
        urls,
        connect: vitest_1.vi.fn().mockResolvedValue(undefined),
        disconnect: vitest_1.vi.fn().mockResolvedValue(undefined),
        sendMessage: vitest_1.vi.fn().mockResolvedValue(undefined)
    }))
}));
// Mock logger
vitest_1.vi.mock('pino', () => ({
    default: vitest_1.vi.fn().mockReturnValue({
        info: vitest_1.vi.fn(),
        error: vitest_1.vi.fn(),
        warn: vitest_1.vi.fn(),
        debug: vitest_1.vi.fn()
    })
}));
// Set test environment variables
process.env.NODE_ENV = 'test';
process.env.LOG_LEVEL = 'error';
//# sourceMappingURL=vitest.setup.js.map